This UDF converts result types from urlbar events ([engagement](https://dictionary.telemetry.mozilla.org/apps/firefox_desktop/metrics/urlbar_engagement), [impression](https://dictionary.telemetry.mozilla.org/apps/firefox_desktop/metrics/urlbar_impression), [abandonment](https://dictionary.telemetry.mozilla.org/apps/firefox_desktop/metrics/urlbar_abandonment)) into [product-friendly names](https://docs.google.com/document/d/1kmlAykJR7r7VcWe-mfk5R4MvhMvfUao7VrZP_M2t6nY/edit#heading=h.ksu5pbt3aa6k).
